==> apache-johnzon-1.0.2-src.zip: apache-johnzon-1.0.2-src/johnzon-core/src/test/java/org/apache/johnzon/core/JsonBuilderFactoryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.johnzon.core;

import java.util.Collections;

import javax.json.Json;
import javax.json.JsonBuilderFactory;
import javax.json.JsonObject;

import org.junit.Assert;
import org.junit.Test;


public class JsonBuilderFactoryTest {

    @Test
    public void testCreateBuilderFactory() {
        JsonBuilderFactory factory = Json.createBuilderFactory(Collections.EMPTY_MAP);
        JsonObject jsonObject = factory.createObjectBuilder().
                add("name", "home").
                add("city", "Vienna")
                .build();

        //JsonObject
        Assert.assertEquals("home", jsonObject.getString("name"));
        Assert.assertEquals("Vienna", jsonObject.getString("city"));

    }
}

==> apache-johnzon-1.2.22-src.zip: apache-johnzon-1.2.22-src/johnzon-core/src/test/java/org/apache/johnzon/core/JsonBuilderFactoryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.johnzon.core;

import java.util.Collections;

import javax.json.Json;
import javax.json.JsonBuilderFactory;
import javax.json.JsonObject;

import org.junit.Assert;
import org.junit.Test;


public class JsonBuilderFactoryTest {

    @Test
    public void testCreateBuilderFactory() {
        JsonBuilderFactory factory = Json.createBuilderFactory(Collections.emptyMap());
        JsonObject jsonObject = factory.createObjectBuilder().
                add("name", "home").
                add("city", "Vienna")
                .build();

        //JsonObject
        Assert.assertEquals("home", jsonObject.getString("name"));
        Assert.assertEquals("Vienna", jsonObject.getString("city"));

    }
}
